set more off
cd "...\Replication files\JeDEM\Stata output" /* Plug in directory */
capture log close
log using JeDEM.log, replace


*		************************************************************************		*
*		************************************************************************		*
*		  File:				JeDEM.do													*
*		  Date:				September 2014												*
*		  Author:			MG															*
*		  Purpose:			Review of internet voting for expatriates (JEDEM)			*
*		  Input file:		Multiple													*
*		  Log file:			JEDEM.log													*
*		  Data output:		None														*
*		  Machine:			Office laptop												*
*		  Stata version:	11.2														*
*		************************************************************************		*
*		************************************************************************		*


*******************
** Install programs
*******************

ssc install spmap, replace
ssc install shp2dta, replace
ssc install twfe, replace


*********************************************
** Data preparations: Usage of online channel
*********************************************

clear
insheet using "...\Replication files\JeDEM\Data sets\E-Voting_Dataset.csv", delim(;) names  /* Plug in directory */

format municipality %50s

* Drop empty observations
drop if date == ""

* Destringing
destring votes, force replace
destring  evotes, force replace

* Retain only federal votes
drop if levels == 2 | levels == 3 | levels == 6

* Drop three obs in Zurich which include both residents and Swiss abroad
drop if canton == "Zurich" & group == 3 | canton == "Zurich" & group == 6

* Expatriate identifier (1= expatriate, 0 = residents)
	* In Neuchatel, residents category includes expatriates and, in some cases, foreigners before June 2013
gen sa = 0	
replace sa = 1 if group == 2
replace sa = 1 if group == 3 

* Convert date & create year, month, and day variables
gen date2 = date(date, "YMD")
gen year = year(date2)
gen month = month(date2)
gen day = day(date2)
order date2 year month day, after(date)

* English canton identifier
gen canton_engl = ""
replace canton_engl = "Argovia" if canton == "Aargau"
replace canton_engl = "Basel-City" if canton == "Basel-Stadt"
replace canton_engl = "Berne" if canton == "Bern"
replace canton_engl = "Fribourg" if canton == "Fribourg"
replace canton_engl = "Geneva" if canton == "Geneva"
replace canton_engl = "Grisons" if canton == "Graubnden"
replace canton_engl = "Lucerne" if canton == "Lucerne"
replace canton_engl = "Neuchtel" if canton == "Neuchatel"
replace canton_engl = "Schaffhausen" if canton == "Schaffhausen"
replace canton_engl = "Solothurn" if canton == "Solothurn"
replace canton_engl = "St. Gallen" if canton == "St. Gallen"
replace canton_engl = "Thurgau" if canton == "Thurgau"
replace canton_engl = "Zurich" if canton == "Zurich"

* Collapse to canton-voter group-referendum vote format (case-wise deletion)
collapse (sum) votes (sum) evotes (mean) year (mean) month (mean) day, by(canton_engl sa date2) cw

* Share of online voters in all voters
gen ivoteshare = evotes/votes*100

* Collapse to annual means (canton-voter group-year)
collapse (mean)ivoteshare, by(canton_engl sa year)

* Label variables
label var sa "Swiss abroad (=1) or Residents (=0)"
label var canton_engl "Canton"
label var year "Year"
label var ivoteshare "Share of i-votes in total votes (in %)"

save "ivoteshares.dta", replace


*************************************************
** Data preparations: Selects Swiss Abroad Survey
*************************************************

use "...\Replication files\JeDEM\Data sets\SELECTS 2011 - Swiss Abroad.dta", replace /* Plug in directory */

* Drop the six Rs whose country of residence is Switzerland (thus no longer Swiss abroad)
drop if ach10000 == 8100

* Dummy denoting the four cantons where i-voting was available in 2011 federal elections
gen ivotect =0 
replace ivotect = 1 if f10000==12
replace ivotect = 1 if f10000==17
replace ivotect = 1 if f10000==19
replace ivotect = 1 if f10000==18
label var ivotect "Canton with i-voting (dummy)"

* Wassenaar identifier
gen wassenaar = 	0
replace wassenaar = 	1	if ach10000==	8204
replace wassenaar = 	1	if ach10000==	8206
replace wassenaar = 	1	if ach10000==	8207
replace wassenaar = 	1	if ach10000==	8211
replace wassenaar = 	1	if ach10000==	8212
replace wassenaar = 	1	if ach10000==	8214
replace wassenaar = 	1	if ach10000==	8215
replace wassenaar = 	1	if ach10000==	8216
replace wassenaar = 	1	if ach10000==	8218
replace wassenaar = 	1	if ach10000==	8223
replace wassenaar = 	1	if ach10000==	8224
replace wassenaar = 	1	if ach10000==	8226
replace wassenaar = 	1	if ach10000==	8227
replace wassenaar = 	1	if ach10000==	8228
replace wassenaar = 	1	if ach10000==	8229
replace wassenaar = 	1	if ach10000==	8230
replace wassenaar = 	1	if ach10000==	8231
replace wassenaar = 	1	if ach10000==	8232
replace wassenaar = 	1	if ach10000==	8234
replace wassenaar = 	1	if ach10000==	8236
replace wassenaar = 	1	if ach10000==	8239
replace wassenaar = 	1	if ach10000==	8240
replace wassenaar = 	1	if ach10000==	8242
replace wassenaar = 	1	if ach10000==	8244
replace wassenaar = 	1	if ach10000==	8250
replace wassenaar = 	1	if ach10000==	8251
replace wassenaar = 	1	if ach10000==	8261
replace wassenaar = 	1	if ach10000==	8262
replace wassenaar = 	1	if ach10000==	8264
replace wassenaar = 	1	if ach10000==	8265
replace wassenaar = 	1	if ach10000==	8349
replace wassenaar = 	1	if ach10000==	8401
replace wassenaar = 	1	if ach10000==	8423
replace wassenaar = 	1	if ach10000==	8427
replace wassenaar = 	1	if ach10000==	8439
replace wassenaar = 	1	if ach10000==	8515
replace wassenaar = 	1	if ach10000==	8539
replace wassenaar = 	1	if ach10000==	8601
replace wassenaar = 	1	if ach10000==	8607
label var wassenaar "R resides in Wassenaar country"

* Dummy indicating whether R had access to internet voting or not
gen ivoteposs = 0
replace ivoteposs = 1 if ivotect == 1 & wassenaar == 1
label var ivoteposs "Access to internet voting"

* Turnout in the 2011 federal elections
gen turnout = f11100_d

*  Usage of internet channel
	* f11151 identifies Rs who indicated to have voted online
	* Yet some of those claiming to have voted online were (according to their responses) not registered
	* in one of the four cantons where i-voting was actually possible or resided outside the Wassenaar context
	* In other words, some Rs who indicated to have voted online cannot have voted online
	* These will be excluded (the variable is coded only for the four cantons where i-voting was possible and Rs in Wassenaar context)

gen ivoter = 0 if ivoteposs == 1 & turnout == 1
replace ivoter = 1 if f11151 == 1 & ivoteposs == 1 & turnout == 1
label var ivoter "R voted online"

* Sex
gen female = 0 if f00020==1
replace female = 1 if f00020==2
label var female "Female sex"

* Age
order age, after(female)
label var age "Age in years"

* Education
gen edu = educ_rr
label var edu "Education (8-point)"

* Political interest
gen interest = (f10100_a*-1)+4
label var interest "Political interest"
label define interest 0 "Not interested at all" 1 "Rather not interested" 2 "Rather interested" 3 "Very intersted", replace
label value interest interest

* Marriage status
gen married = 0 if marital !=. & marital != .a
replace married = 1 if marital == 2
label var married "Married"

* PID
gen pid = (f14000r_ach*-1)+3
label var pid "Party identification"
label define pid 0 "Not close to any party" 1 "Somewhat closer to a party" 2 "Close to a party", replace
label value pid pid

* Political knowledge
gen know = scalknowABROAD
label var know "Political knowledge"

* Neighbour country identifier
gen neighbour = 	0
replace neighbour = 	1	if ach10000==	8207
replace neighbour = 	1	if ach10000==	8212
replace neighbour = 	1	if ach10000==	8218
replace neighbour = 	1	if ach10000==	8229
label var neighbour "R resides in neighbour country"

* Left-right
gen leftright = f15200
label var leftright "Left-right self-placement"

* Save data set
save "Selects2011_SA.dta", replace


*****************************************
** Data preparations: Mobilization effect
*****************************************

clear
insheet using "...\Replication files\JeDEM\Data sets\Auslandschweizerstatistik_nach_Wohnland.csv", delim(;)
tab country

* Combine Yugoslavia & Serbia (coded as two states in 2006 and beyond)
replace country = "Yugoslavia" if country == "Jugoslawien (Serbien, Montenegro)" | country == "Serbien"

* Assign dependencies to mother country
gen territory = country
replace country = "Grossbritannien" if country == "Alderney"
replace country = "Grossbritannien" if country == "Anguilla"
replace country = "Grossbritannien" if country == "Bermuda"
replace country = "Grossbritannien" if country == "Cayman Inseln"
replace country = "Grossbritannien" if country == "Gibraltar"
replace country = "Grossbritannien" if country == "Guernsey"
replace country = "Grossbritannien" if country == "Insel Man"
replace country = "Grossbritannien" if country == "Jersey"
replace country = "Grossbritannien" if country == "Jungferninseln (UK)"
replace country = "Grossbritannien" if country == "Turks- und Caicosinseln"

replace country = "Niederlande" if country == "Aruba"
replace country = "Niederlande" if country == "Bonaire, St. Eustatius und Saba"
replace country = "Niederlande" if country == "Curaao"
replace country = "Niederlande" if country == "Niederlndische Antillen"
replace country = "Niederlande" if country == "Sint Maarten"

replace country = "Frankreich" if country == "Franzsisch-Guayana"
replace country = "Frankreich" if country == "Franzsisch-Polynesien"
replace country = "Frankreich" if country == "Guadeloupe"
replace country = "Frankreich" if country == "Martinique"
replace country = "Frankreich" if country == "Mayotte"
replace country = "Frankreich" if country == "Neukaledonien"
replace country = "Frankreich" if country == "Reunion"
replace country = "Frankreich" if country == "Saint-Martin"
replace country = "Frankreich" if country == "St. Pierre und Miquelon"

replace country = "Dnemark" if country == "Frer"
replace country = "Dnemark" if country == "Grnland"

replace country = "China" if country == "Hongkong"
replace country = "China" if country == "Macao"

replace country = "Norwegen" if country == "Svalbard und Jan Mayen"

replace country = "Israel" if country == "Palstina"

replace country = "Vereinigte Staaten von Amerika" if country == "Puerto Rico"

* Combine dependencies with mother countries
collapse (sum) berechtigt (sum) eingeschrieben (mean) europa - ozeanien, by(country year)

* Encode country
encode country, gen(countrycode)

* Code regions
bysort countrycode: egen europe = mean(europa)
bysort countrycode: egen africa = mean(afrika)
bysort countrycode: egen asia = mean(asien)
bysort countrycode: egen america = mean(amerika)
bysort countrycode: egen oceania = mean(ozeanien)
replace america = 0 if country == "Grossbritannien"
replace africa = 1 if country == "Sdsudan"
gen aggregates = 0
replace aggregates = 1 if country == "Insgesamt"
replace aggregates = 1 if country == "Asien"
replace aggregates = 1 if country == "Afrika"
replace aggregates = 1 if country == "Europa"
replace aggregates = 1 if country == "EU-Staaten"
replace aggregates = 1 if country == "Ozeanien"
replace aggregates = 1 if country == "Amerika"
foreach var of varlist europe - oceania {
replace `var' = 0 if `var' == . & aggregates == 0
}
drop europa - ozeanien

* Registration rate
gen rate = (eingeschrieben / berechtigt) * 100
label var rate "Registration rate in %"

* Identifiers for small cluster
bysort country : egen cluster_min = min(berechtigt)
gen tops_100 = (cluster_min > 100)
gen tops_200 = (cluster_min > 200)
gen tops_500 = (cluster_min > 500)
gen tops_1000 = (cluster_min > 1000)

* Wassenaar identifier
gen wassenaar = 0
replace wassenaar = 1 if country == "Belgien"
replace wassenaar = 1 if country == "Bulgarien"
replace wassenaar = 1 if country == "Dnemark"
replace wassenaar = 1 if country == "Deutschland"
replace wassenaar = 1 if country == "Estland"
replace wassenaar = 1 if country == "Finnland"
replace wassenaar = 1 if country == "Frankreich"
replace wassenaar = 1 if country == "Griechenland"
replace wassenaar = 1 if country == "Grossbritannien"
replace wassenaar = 1 if country == "Niederlande"
replace wassenaar = 1 if country == "Irland"
replace wassenaar = 1 if country == "Italien"
replace wassenaar = 1 if country == "Lettland"
replace wassenaar = 1 if country == "Litauen"
replace wassenaar = 1 if country == "Luxemburg"
replace wassenaar = 1 if country == "Malta"
replace wassenaar = 1 if country == "sterreich"
replace wassenaar = 1 if country == "Polen"
replace wassenaar = 1 if country == "Portugal"
replace wassenaar = 1 if country == "Rumnien"
replace wassenaar = 1 if country == "Schweden"
replace wassenaar = 1 if country == "Slowakei"
replace wassenaar = 1 if country == "Slowenien"
replace wassenaar = 1 if country == "Spanien"
replace wassenaar = 1 if country == "Tschechische Republik"
replace wassenaar = 1 if country == "Ungarn"
replace wassenaar = 1 if country == "Zypern"
replace wassenaar = 1 if country == "Argentinien"
replace wassenaar = 1 if country == "Australien"
replace wassenaar = 1 if country == "Japan"
replace wassenaar = 1 if country == "Kanada"
replace wassenaar = 1 if country == "Kroatien"
replace wassenaar = 1 if country == "Mexiko"
replace wassenaar = 1 if country == "Neuseeland"
replace wassenaar = 1 if country == "Norwegen"
replace wassenaar = 1 if country == "Russland"
replace wassenaar = 1 if country == "Sdafrika"
replace wassenaar = 1 if country == "Sdkorea"
replace wassenaar = 1 if country == "Trkei"
replace wassenaar = 1 if country == "Ukraine"
replace wassenaar = 1 if country == "Vereinigte Staaten von Amerika"
replace wassenaar = 1 if country == "Andorra"
replace wassenaar = 1 if country == "Liechtenstein"
replace wassenaar = 1 if country == "Monaco"
replace wassenaar = 1 if country == "San Marino"
replace wassenaar = 1 if country == "Vatikan"

replace wassenaar = . if country == "Insgesamt"
replace wassenaar = . if country == "Europa"
replace wassenaar = . if country == "Afrika"
replace wassenaar = . if country == "Amerika"
replace wassenaar = . if country == "Asien"
replace wassenaar = . if country == "Ozeanien"
replace wassenaar = . if country == "EU-Staaten"

* I-voting availability from 2008
gen ivoting = 0
replace ivoting = 1 if year > 2007 & wassenaar == 1

* Unit-specific trend variables
forvalues i = 1(1)204 {
	egen trend`i' = seq() if countrycode == `i'
	replace trend`i' = 0 if countrycode != `i'
}

save mobilization.dta, replace

****************************
** Map i-voting availability
****************************

cd "...\Replication files\JeDEM\Data sets\shapefile" /* Plug in directory */

* Import data and create map
shp2dta using G2K12, data("swi_data") coor("swi_coordinates") genid(id) replace
use swi_data, replace
list id NAME
gen system = .
replace system = 1 if id == 21
replace system = 3 if id == 19
replace system = 4 if id == 16
replace system = 2 if id == 2
replace system = 2 if id == 20
replace system = 2 if id == 4
replace system = 5 if id == 6
replace system = 5 if id == 25
replace system = 5 if id == 1
replace system = 5 if id == 13
replace system = 5 if id == 11
replace system = 5 if id == 5
replace system = 5 if id == 9
label define system 1 "Geneva" 2 "Non-pilots (Geneva system)" 3 "Neuchtel" 4 "Zurich" 5 "Non-pilots (Zurich system)", replace
label value system system 

spmap system using swi_coordinates, id(id) clmethod(unique) fcolor(red red*.5 green midblue midblue*.5) ///
	legend(order(2 3 4 5 6) size(vsmall) symxsize(*1) cols(1) pos(11) region(lcolor(white))) ///
	note("Note: Zurich suspended i-voting in 2011.", size(small))
* Go back to Stata output directory and export graph (Figure 1)
cd "...\Replication files\JeDEM\Stata output"  /* Plug in directory */
graph export "Figure 1.emf", replace


*************************
** Popularity of i-voting
*************************

use "ivoteshares.dta", replace

* I-voter share: expatriates
* Figure 2
twoway 	(connected ivoteshare year if canton == "Argovia" & sa == 1, sort color(dknavy) msymbol(circle_hollow) cmissing(n)) ///
		(connected ivoteshare year if canton == "Basel-City" & sa == 1, sort color(sand) msymbol(circle_hollow) cmissing(n)) ///
		(connected ivoteshare year if canton == "Berne" & sa == 1, sort color(lavender) msymbol(circle_hollow)  cmissing(n)) ///
		(connected ivoteshare year if canton == "Fribourg" & sa == 1, sort color(maroon) msymbol(circle_hollow) cmissing(n)) ///
		(connected ivoteshare year if canton == "Geneva" & sa == 1, sort color(red) msymbol(circle_hollow) cmissing(n))	///
		(connected ivoteshare year if canton == "Lucerne" & sa == 1, sort color(dkorange) msymbol(circle_hollow) cmissing(n)) ///	
		(connected ivoteshare year if canton == "Neuchtel" & sa == 1, sort color(green) msymbol(circle_hollow) cmissing(n)) ///		
		(connected ivoteshare year if canton == "St. Gallen" & sa == 1, sort color(erose) msymbol(circle_hollow) cmissing(n))	///
		(connected ivoteshare year if canton == "Thurgau" & sa == 1, sort color(cranberry) msymbol(circle_hollow) cmissing(n)), ///
		xscale(range(2009 2014) nofextend) ///
		xlabel(2009(1)2014, angle(forty_five) labsize(small) grid glcolor(ltbluishgray) gmin gmax) ///
		xtitle("Year", margin(small)) ///
		yscale(range(0 70) nofextend) ///
		ylabel(0(10)70, angle(horizontal) labsize(small) grid glcolor(ltbluishgray) gmin gmax) ///
		ymlabel(5(10)65, nolabels) ///
		ytitle("I-voting rate (%)", margin(small)) ///
		scheme(s2color) xsize(15) ysize(10) scale(1.2) graphregion(fcolor(white) lcolor(white)) ///
		legend(order(1 "Argovia" 2 "Basel-City" 3 "Berne" 4 "Fribourg" 5 "Geneva" 6 "Lucerne" 7 "Neuchtel" 8 "St. Gallen" 9 "Thurgau")  size(small) symxsize(*.7) cols(1) pos(3) region(lcolor(white)))
graph export "Figure 2.emf", replace
	
* Looking at time trends
preserve
drop if sa == 0
encode canton, gen(ctcode)
tsset ctcode year
gen fd = ivoteshare - L.ivoteshare
sum fd
sum fd if year != 2014
scatter 
bysort year: sum fd if year != 2014
restore

* I-voter share: residents
* We need to tell Stata that data for Geneva, 2005-2007 is missing (manually code empty observations)
set obs 69
replace canton = "Geneva" in 67
replace year = 2005 in 67
replace ivoteshare = . in 67
replace canton = "Geneva" in 68
replace year = 2006 in 68
replace ivoteshare = . in 68
replace canton = "Geneva" in 69
replace year = 2007 in 69
replace ivoteshare = . in 69
replace sa = 0 in 67/69
sort canton sa year

* Figure 3
twoway 	(connected ivoteshare year if canton == "Geneva" & sa == 0, sort color(red) msymbol(circle_hollow) cmissing(n)) ///
		(connected ivoteshare year if canton == "Neuchtel" & sa == 0, sort color(green) msymbol(circle_hollow) cmissing(n)) ///
		(connected ivoteshare year if canton == "Zurich" & sa == 0, sort color(blue) msymbol(circle_hollow)  cmissing(n)), ///
		xscale(range(2004 2014) nofextend) ///
		xlabel(2004(2)2014, angle(forty_five) labsize(small) grid glcolor(ltbluishgray) gmin gmax) ///
		xmlabel(2005(2)2013, nolabels) ///
		xtitle("Year", margin(small)) ///
		yscale(range(0 50) nofextend) ///
		ylabel(0(10)50, angle(horizontal) labsize(small) grid glcolor(ltbluishgray) gmin gmax) ///
		ymlabel(5(10)45, nolabels) ///
		ytitle("I-voting rate (%)", margin(small)) ///
		scheme(s2color) xsize(15) ysize(10) scale(1.2) graphregion(fcolor(white) lcolor(white)) ///
		legend(order(1 "Geneva" 2 "Neuchtel" 3 "Zurich") size(small) symxsize(*.7) cols(1) pos(3) region(lcolor(white)))
graph export "Figure 3.emf", replace


**********************************************
** Characteristics of expatriate online voters
**********************************************

use "Selects2011_SA.dta", replace

* Table 3: Differences in means between i-voters and "traditional" voters
foreach var of varlist age female edu married neighbour pid interest know leftright {
di "`var'"
ttest `var', by(ivoter)
}

* Robustness I: chi-square test for binary attributes
foreach var of varlist female married neighbour {
di "`var'"
tab ivoter `var', chi2
}

* Robustness II: Wilcoxon-Mann-Whitney test for ordinal attributes
foreach var of varlist edu pid interest know leftright {
di "`var'"
ranksum `var', by(ivoter)
}


**********************
** Mobilization effect
**********************

use mobilization.dta, replace

* Drop aggregates
drop if aggregates == 1

* FE models (Table 4)
* Model 1
areg rate ivoting i.year if tops_500 == 1 & country !="China" & country !="Singapur", absorb(countrycode) cl(countrycode)
* Model 2
twfe rate ivoting if tops_500 == 1 & country !="China" & country !="Singapur", ids(countrycode year) cluster(countrycode year)
* Model 3
areg rate ivoting i.year trend* if tops_500 == 1 & country !="China" & country !="Singapur", absorb(countrycode) 
* Model 4
areg rate ivoting i.year if tops_500 == 1 , absorb(countrycode) cl(countrycode)
* Model 5
areg rate ivoting i.year if tops_200 == 1 & country !="China" & country !="Singapur", absorb(countrycode) cl(countrycode)
* Model 6
areg rate ivoting i.year if tops_1000 == 1 & country !="China" & country !="Singapur", absorb(countrycode) cl(countrycode)

* Graph average rate of registered over time by i-voting availability (Figure 4)
gen avg_rate = .
forvalues i = 2001(1)2013 {
	sum rate if year == `i' & wassenaar == 0 & tops_500 == 1 & country != "China" & country != "Singapur"
	replace avg_rate = r(mean) if year == `i' & wassenaar == 0 & tops_500 == 1
	sum rate if year == `i' & wassenaar == 1 & tops_500 == 1
	replace avg_rate = r(mean) if year == `i' & wassenaar == 1 & tops_500 == 1
}

twoway (line avg_rate year if country == "Frankreich", sort lcolor(black) lpattern(solid) connect(direct) cmissing(n)) ///
	(line avg_rate year if country == "China", sort lcolor(black) lpattern(dash_dot) connect(direct) cmissing(n)) ///
	(pcarrowi 9 2006 14 2007.92), ///
	ytitle("Registration rate (%)") yscale(nofextend) /// 
	ylabel(0(5)30, labsize(small) grid glcolor(gs10) glpattern(dot) gmin gmax) ymlabel(2.5(5)27.5, nolabels) xtitle(Year) ///
	xscale(nofextend range(2001 2013)) xlabel(2001(2)2013, labsize(small) angle(forty_five)) xmlabel(2002(2)2012, nolabels) caption("") note("") ///
	legend(on order(1 2) label(1 "I-voting countries") label(2 "Non-i-voting countries") symxsize(*.6) position(12) symplacement(center) size(small)) ///
	xline(2008, lpattern(shortdash) noextend) ///
	text(9 2004 "The first canton (NE)" "introduced i-voting", place(se) just(left) size(small)) ///
	xsize(8) ysize(6) scale(1.4)
graph export "Figure 4.emf", replace


log close
